@@ -8,11 +8,11 @@
 #
 
 import os
-from django.core.management import execute_manager
+import sys
 
 # note that we're actually running the testrunner project, not the salesforce app.
 os.environ['DJANGO_SETTINGS_MODULE'] = 'salesforce.testrunner.settings'
 
 if __name__ == "__main__":
-	from salesforce.testrunner import settings
-	execute_manager(settings)
+	from django.core.management import execute_from_command_line
+	execute_from_command_line(sys.argv)
