@@ -9,8 +9,10 @@
 Salesforce database backend for Django.
 """
 
+from __future__ import print_function
 import logging
 import requests
+import sys
 
 from django.core.exceptions import ImproperlyConfigured
 from django.db.backends import BaseDatabaseFeatures, BaseDatabaseWrapper
@@ -47,7 +49,8 @@ class SalesforceError(DatabaseError):
 		self.response = response
 		self.verbose = verbose
 		if verbose:
-			print("Error (debug details) %s\n%s" % (response.text, response.__dict__))
+			print("Error (debug details) %s\n%s" % (response.text,
+					response.__dict__), file=sys.stderr)
 
 
 
@@ -90,8 +93,6 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 		'endswith': 'LIKE %s',
 		'istartswith': 'LIKE %s',
 		'iendswith': 'LIKE %s',
-		# TODO remove 'isnull' because it's incorrect and unused
-		#'isnull': '!= %s',
 	}
 
 	Database = Database
@@ -110,7 +111,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 		self.validation = DatabaseValidation(self)
 		self.sf_session = requests.Session()
 		self.sf_session.auth = SalesforceAuth(db_alias=alias)
-		sf_instance_url = authenticate(settings_dict=settings_dict)['instance_url']
+		sf_instance_url = authenticate(alias, settings_dict=settings_dict)['instance_url']
 		sf_requests_adapter = requests.adapters.HTTPAdapter(max_retries=MAX_RETRIES)
 		self.sf_session.mount(sf_instance_url, sf_requests_adapter)
 		# Additional header works, but the improvement unmeasurable for me.
