@@ -4,18 +4,20 @@
 # (c) 2012-2013 Freelancers Union (http://www.freelancersunion.org)
 # See LICENSE.md for details
 #
-
+from __future__ import print_function
 from decimal import Decimal
 import datetime
 import pytz
 import random
 import string
+import sys
 
 from django.conf import settings
 from django.db import connections
 from django.db.models import Q, Avg, Count, Sum, Min, Max
 from django.test import TestCase
 from django.utils.unittest import skip, skipUnless
+from django.utils import timezone
 
 from salesforce.testrunner.example.models import (Account, Contact, Lead, User,
 		BusinessHours, ChargentOrder, CronTrigger,
@@ -29,33 +31,33 @@ import logging
 log = logging.getLogger(__name__)
 
 random_slug = ''.join(random.choice(string.ascii_uppercase + string.ascii_lowercase + string.digits) for x in range(32))
-current_user = settings.DATABASES['salesforce']['USER']
+sf_alias = getattr(settings, 'SALESFORCE_DB_ALIAS', 'salesforce')
+current_user = settings.DATABASES[sf_alias]['USER']
 test_email = 'test-djsf-unittests-%s@example.com' % random_slug
-sf_tables = [x['name'] for x in
-		connections['salesforce'].introspection.table_list_cache['sobjects']
-		]
-
+sf_tables = []
+if router.is_sf_database(sf_alias):
+	sf_tables = [x['name'] for x in
+			connections[sf_alias].introspection.table_list_cache['sobjects']]
+sf_databases = [db for db in connections if router.is_sf_database(db)]
+default_is_sf = router.is_sf_database(sf_alias)
 
 def refresh(obj):
 	"""
-	Get the same object refreshed from db.
+	Get the same object refreshed from the same db.
 	"""
-	return obj.__class__.objects.get(pk=obj.pk)
+	db = obj._state.db
+	return type(obj).objects.using(db).get(pk=obj.pk)
 	
-def round_datetime_utc(timestamp):
-	"""Round to seconds and set zone to UTC."""
-	## sfdates are UTC to seconds precision but use a fixed-offset
-	## of +0000 (as opposed to a named tz)
-	timestamp = timestamp.replace(microsecond=0)
-	timestamp = timestamp.replace(tzinfo=pytz.utc)
-	return timestamp
-
 
 class BasicSOQLTest(TestCase):
 	def setUp(self):
 		"""
 		Create our test lead record.
 		"""
+		def add_obj(obj):
+			obj.save()
+			self.objs.append(obj)
+		#
 		self.test_lead = Lead(
 			FirstName	= "User",
 			LastName	= "Unittest General",
@@ -63,15 +65,26 @@ class BasicSOQLTest(TestCase):
 			Status		= 'Open',
 			Company = "Some company, Ltd.",
 		)
+		self.objs = []
 		self.test_lead.save()
+		if not default_is_sf:
+			add_obj(Contact(LastName='Test contact 1'))
+			add_obj(Contact(LastName='Test contact 2'))
+			add_obj(User(Username=current_user))
 	
 	def tearDown(self):
 		"""
-		Clean up our test lead record.
+		Clean up our test records.
 		"""
-		self.test_lead.delete()
+		if self.test_lead.pk is not None:
+			self.test_lead.delete()
+		for obj in self.objs:
+			if obj.pk is not None:
+				obj.delete()
+		self.objs = []
 
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_raw(self):
 		"""
 		Get the first two contact records.
@@ -85,6 +98,7 @@ class BasicSOQLTest(TestCase):
 		self.assertEqual(len(contacts), 2)
 		'%s' % contacts[0].__dict__  # Check that all fields are accessible
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_raw_foreignkey_id(self):
 		"""
 		Get the first two contacts by raw query with a ForeignKey id field.
@@ -114,6 +128,7 @@ class BasicSOQLTest(TestCase):
 		leads = Lead.objects.exclude(Email="steve@apple.com", LastName="Unittest General").filter(FirstName="User", LastName="Unittest General")
 		self.assertEqual(leads.count(), 1)
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_foreign_key(self):
 		"""
 		Verify that the owner of an Contact is the currently logged admin.
@@ -148,33 +163,33 @@ class BasicSOQLTest(TestCase):
 		"""
 		Test updating a date.
 		"""
-		now = round_datetime_utc(datetime.datetime.utcnow())
-		contact = Contact.objects.all()[0]
-		old_date = contact.EmailBouncedDate
-		contact.EmailBouncedDate = now.replace(tzinfo=pytz.utc)
+		now = timezone.now().replace(microsecond=0)
+		contact = Contact(FirstName = 'sf_test', LastName='my')
 		contact.save()
+		contact = refresh(contact)
 		try:
+			contact.EmailBouncedDate = now
+			contact.save()
 			self.assertEqual(refresh(contact).EmailBouncedDate, now)
 		finally:
-			contact.EmailBouncedDate = old_date
-			contact.save()
-		self.assertEqual(refresh(contact).EmailBouncedDate, old_date)
+			contact.delete()
 	
 	def test_insert_date(self):
 		"""
 		Test inserting a date.
 		"""
-		now = round_datetime_utc(datetime.datetime.utcnow())
+		now = timezone.now().replace(microsecond=0)
 		contact = Contact(
 				FirstName = 'Joe',
 				LastName = 'Freelancer',
-				EmailBouncedDate=now.replace(tzinfo=pytz.utc))
+				EmailBouncedDate=now)
 		contact.save()
 		try:
 			self.assertEqual(refresh(contact).EmailBouncedDate, now)
 		finally:
 			contact.delete()
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_default_specified_by_sf(self):
 		"""
 		Verify that an object with a field with default value specified by some
@@ -207,6 +222,8 @@ class BasicSOQLTest(TestCase):
 		lead = Lead.objects.get(Email=test_email)
 		self.assertEqual(lead.FirstName, 'User')
 		self.assertEqual(lead.LastName, 'Unittest General')
+		if not default_is_sf:
+			self.skipTest("Default database should be any Salesforce.")
 		# test a read only field (formula of full name)
 		self.assertEqual(lead.Name, 'User Unittest General')
 	
@@ -250,7 +267,9 @@ class BasicSOQLTest(TestCase):
 		"""
 		Test that date comparisons work properly.
 		"""
-		today = round_datetime_utc(datetime.datetime(2013, 8, 27))
+		today = datetime.datetime(2013, 8, 27)
+		if settings.USE_TZ:
+			today = timezone.make_aware(today, pytz.utc)
 		yesterday = today - datetime.timedelta(days=1)
 		tomorrow = today + datetime.timedelta(days=1)
 		contact = Contact(FirstName='sf_test', LastName='date',
@@ -264,6 +283,7 @@ class BasicSOQLTest(TestCase):
 		finally:
 			contact.delete()
 	
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_insert(self):
 		"""
 		Create a lead record, and make sure it ends up with a valid Salesforce ID.
@@ -299,6 +319,7 @@ class BasicSOQLTest(TestCase):
 		test_lead.save()
 		self.assertEqual(refresh(test_lead).FirstName, 'Tested')
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_decimal_precision(self):
 		"""
 		Ensure that the precision on a DecimalField of a record saved to
@@ -356,6 +377,7 @@ class BasicSOQLTest(TestCase):
 		# The reliability of this is only 99.9%, therefore it is commented out.
 		#self.assertNotEqual(trigger.PreviousFireTime.microsecond, 0)
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_time_field(self):
 		"""
 		Test a TimeField (read, modify, verify).
@@ -401,6 +423,7 @@ class BasicSOQLTest(TestCase):
 		User.objects.get(Username__iendswith=current_user[1:].upper())
 		# Operators regex and iregex not tested because they are not supported.
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_unsupported_bulk_create(self):
 		"""
 		Unsupported bulk_create: "Errors should never pass silently."
@@ -413,7 +436,7 @@ class BasicSOQLTest(TestCase):
 		Test that single quotes in strings used in filtering a QuerySet
 		are escaped properly.
 		"""
-		account_name = '''Dr. Evil's Giant "Laser", LLC'''
+		account_name = '''Dr. Evil's Giant\\' "Laser", LLC'''
 		account = Account(Name=account_name)
 		account.save()
 		try:
@@ -421,15 +444,16 @@ class BasicSOQLTest(TestCase):
 		finally:
 			account.delete()
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_escape_single_quote_in_raw_query(self):
 		"""
 		Test that manual escaping within a raw query is not double escaped.
 		"""
-		account_name = '''Dr. Evil's Giant "Laser", LLC'''
+		account_name = '''Dr. Evil's Giant\\' "Laser", LLC'''
 		account = Account(Name=account_name)
 		account.save()
 
-		manually_escaped = '''Dr. Evil\\'s Giant "Laser", LLC'''
+		manually_escaped = '''Dr. Evil\\'s Giant\\\\\\' "Laser", LLC'''
 		try:
 			retrieved_account = Account.objects.raw(
 				"SELECT Id, Name FROM Account WHERE Name = '%s'" % manually_escaped)[0]
@@ -453,6 +477,7 @@ class BasicSOQLTest(TestCase):
 		len(Contact.objects.filter(Q(FirstName=u'\xe1') | Q(LastName=u'\xe9')))
 		len(Contact.objects.filter(Q(FirstName='\xc3\xa1') | Q(LastName='\xc3\xa9')))
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_aggregate_query(self):
 		"""
 		Test for different aggregate function.
@@ -495,10 +520,15 @@ class BasicSOQLTest(TestCase):
 		"""
 		self.test_lead.delete()
 		# TODO optimize counting because this can load thousands of records
-		count_deleted = Lead.objects.filter(IsDeleted=True, LastName="Unittest General").query_all().count()
+		count_deleted = Lead.objects.db_manager(sf_alias).query_all().filter(IsDeleted=True, LastName="Unittest General").count()
+		if not default_is_sf:
+			self.skipTest("Default database should be any Salesforce.")
 		self.assertGreaterEqual(count_deleted, 1)
+		count_deleted2 = Lead.objects.filter(IsDeleted=True, LastName="Unittest General").query_all().count()
+		self.assertGreaterEqual(count_deleted2, count_deleted)
 		self.test_lead.save()  # save anything again to be cleaned finally
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_z_big_query(self):
 		"""
 		Test a big query that will be splitted to more requests.
@@ -511,15 +541,16 @@ class BasicSOQLTest(TestCase):
 			print("Not enough Leads accumulated (currently %d including deleted) "
 					"in the last two weeks that are necessary for splitting the "
 					"query into more requests. Number 1001 or 2001 is enough." %
-					len(leads_list))
+					len(leads_list), file=sys.stderr)
 			self.skipTest("Not enough Leads found for big query test")
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_cursor_execute_fetch(self):
 		"""
 		Get results by cursor.execute(...); fetchone(), fetchmany(), fetchall()
 		"""
 		sql = "SELECT Id, LastName, FirstName, OwnerId FROM Contact LIMIT 2"
-		cursor = connections['salesforce'].cursor()
+		cursor = connections[sf_alias].cursor()
 		cursor.execute(sql)
 		contacts = cursor.fetchall()
 		self.assertEqual(len(contacts), 2)
@@ -528,6 +559,7 @@ class BasicSOQLTest(TestCase):
 		self.assertEqual(cursor.fetchone(), contacts[0])
 		self.assertEqual(cursor.fetchmany(), contacts[1:])
 	
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_errors(self):
 		"""
 		Test for improving code coverage.
@@ -537,15 +569,7 @@ class BasicSOQLTest(TestCase):
 		bad_queryset.query.debug_silent = True
 		self.assertRaises(salesforce.backend.base.SalesforceError, list, bad_queryset)
 
-	def test_expired_auth_id(self):
-		"""
-		Test the code for expired auth ID.
-		"""
-		# simulate that a request with invalid/expired auth ID re-authenticates
-		# and succeeds.
-		salesforce.auth.oauth_data['salesforce']['access_token'] += 'simulated invalid/expired'
-		self.assertEqual(len(Lead.objects.raw("select Id from Lead limit 1")[0].Id), 18)
-
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_generic_type_field(self):
 		"""
 		Test that a generic foreign key can be filtered by type name and
@@ -590,6 +614,7 @@ class BasicSOQLTest(TestCase):
 		v0 = values[0]
 		self.assertEqual(values_list[0], (v0['pk'], v0['FirstName'], v0['LastName']))
 
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
 	def test_double_delete(self):
 		"""
 		Test that repeated delete of the same object is ignored the same way
@@ -609,7 +634,56 @@ class BasicSOQLTest(TestCase):
 		Contact(pk=contact_id).delete()
 		# Id of completely deleted item or fake but valid item.
 		Contact(pk='003000000000000AAA').delete()
-		bad_id = '003000000000000AAB' # Id with an incorrect uppercase mask
-		self.assertRaises(salesforce.backend.base.SalesforceError, Contact(pk=bad_id).delete)
+		#bad_id = '003000000000000AAB' # Id with an incorrect uppercase mask
+		#self.assertRaises(salesforce.backend.base.SalesforceError, Contact(pk=bad_id).delete)
 
-	#@skip("Waiting for bug fix")
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
+	def test_multiple_sf_databases(self):
+		"""
+		Test a connection to two sf databases with the same user.
+		(with sandboxes of the same organization)
+		"""
+		other_dbs = [k for k, v in settings.DATABASES.items() if
+				k != 'salesforce' and v['ENGINE'] == 'salesforce.backend']
+		if not other_dbs:
+			self.skipTest('Only one SF database found.')
+		other_db = other_dbs[0]
+		c1 = Contact(LastName='sf_test 1')
+		c2 = Contact(LastName='sf_test 2')
+		c1.save()
+		c2.save(using=other_db)
+		try:
+			user1 = refresh(c1).Owner
+			user2 = refresh(c2).Owner
+			username1 = user1.Username
+			username2 = user2.Username
+			# Verify different, but similar usernames like usual in sandboxes
+			self.assertNotEqual(user1._state.db, user2._state.db)
+			self.assertNotEqual(username1, username2)
+			self.assertEqual(username1.split('@')[0], username2.split('@')[0])
+		finally:
+			c1.delete()
+			c2.delete()
+
+	@skipUnless(default_is_sf, "Default database should be any Salesforce.")
+	def test_expired_auth_id(self):
+		"""
+		Test the code for expired auth ID for multiple SF databases.
+		No similar test exists for a single db.
+		"""
+		self.assertGreaterEqual(len(sf_databases), 1)
+		objects = []
+		for db in sf_databases:
+			c = Contact(LastName='sf_test %s' % db)
+			c.save(using=db)
+			objects.append(c)
+		try:
+			# simulate that a request with invalid/expired auth ID re-authenticates
+			# and succeeds.
+			for db in sf_databases:
+				salesforce.auth.oauth_data[db]['access_token'] += 'simulated invalid/expired'
+			for x in objects:
+				self.assertTrue(refresh(x))
+		finally:
+			for x in objects:
+				x.delete()
